@@ -5,39 +5,19 @@ from typing import Protocol
 
 class UserModel(Protocol):
     """A protocol for the user model"""
-    sub: str
-    """A unique identifier for the user (is unique for the issuer)"""
-
-    iss: str
-    """The issuer of the token"""
-
-    exp: str
-    """The expiration time of the token"""
-
-    client_id: str
-    """The client_id of the app that requested the token"""
-
-    preferred_username: str
-    """The username of the user"""
-
-    roles: list[str]
-    """The roles of the user"""
-
-    scope: str
-    """The scope of the token"""
-
-    iat: str
-    """The issued at time of the token"""
+    id: int
+    """The id of the user"""
+    
     
     
     
 class ClientModel(Protocol):
     """A protocol for the client model"""
 
-    id: str
+    id: int
     """The id of the client"""
 
-    name: str
+    client_id: str
     """The name of the client"""
     
     
@@ -51,8 +31,16 @@ class ClientModel(Protocol):
 class OrganizationModel(Protocol):
     """A protocol for the organizaition model"""
 
-    id: str
+    id: int
     """The id of the client"""
 
-    identifier: str
-    """The name of orgnaization"""
\ No newline at end of file
+    slug: str
+    """The name of orgnaization"""
+    
+    
+class MembershipModel(Protocol):    
+    """A protocol for the membership model"""
+    
+    id: int
+    """The id of the membership"""
+    
\ No newline at end of file
