@@ -1,7 +1,7 @@
 """ Strawberry extension for Authentikate """
 
 from .extension import AuthentikateExtension
-from .directives import AuthExtension, Auth, all_directives
+from .directives import AuthExtension, Auth, all_directives, AuthSubscribeExtension
 
 
 __all__ = [
