@@ -1,13 +1,13 @@
 import contextvars
 from authentikate.base_models import JWTToken
-from authentikate.protocols import UserModel, ClientModel
+from authentikate.protocols import UserModel, ClientModel, OrganizationModel
 
 
 
 token_var: contextvars.ContextVar[JWTToken | None] = contextvars.ContextVar("token_var", default=None)
 user_var: contextvars.ContextVar[UserModel | None] = contextvars.ContextVar("user_var", default=None)
 client_var: contextvars.ContextVar[ClientModel | None] = contextvars.ContextVar("client_var", default=None)
-organization_var: contextvars.ContextVar[str | None] = contextvars.ContextVar("organization_var", default=None)
+organization_var: contextvars.ContextVar[OrganizationModel | None] = contextvars.ContextVar("organization_var", default=None)
 
 
 def get_token() -> JWTToken | None:
@@ -45,7 +45,7 @@ def get_client() -> ClientModel | None:
     return client_var.get()
 
 
-def get_organization() -> str | None:
+def get_organization() -> OrganizationModel | None:
     """
     Get the current organization from the context variable
 
